program FontApp;

{---------------------------------------------------------------------
Example application for the custom control Font (FntCtls.DLL) of
the SMWCC 2.0 Custom Control Pack

Copyright (C) by Sebastian Modersohn

Note: This code file isn't documented into detail. If you have
      questions to *THIS* code file or want to know some details
      please contact me via CompuServe, ID 100340,1474.
---------------------------------------------------------------------}

{$R FontApp}

uses WinTypes, WinProcs, OWindows, ODialogs, Strings,
     {the import unit; only needed for the help (path and string-ID)}
     FntCtlCo;

{for loading the DLL}
const DLLName        ='FntCtls.DLL';
      em_DLLNotFound =1;

type
  {main window: No object has to be initialized!;
   this object is only necessary for the help-call}
  PFontWindow = ^TFontWindow;
  TFontWindow = object(TDlgWindow)
    procedure Help(var Msg: TMessage);
      virtual id_First + 998;
  end;

{App that loads and frees the DLL and initializes the main window}
  PFontApp = ^TFontApp;
  TFontApp = object(TApplication)
    Lib: THandle;
    constructor Init(AName: PChar);
    destructor Done; virtual;
    procedure InitMainWindow; virtual;
    procedure Error(ErrorCode: Integer); virtual;
  end;


{ TFontWindow }

procedure TFontWindow.Help(var Msg: TMessage);
begin
  WinHelp(HWindow, HelpFile, Help_Context, 100);
end;

{ TFontApp }

constructor TFontApp.Init(AName: PChar);
begin
  {Load the library}
  Lib := LoadLibrary(DLLName);
  {If it wasn't loaded succesfully, then call error with em_DLLNotFound}
  if Lib < 32 then
    Status := em_DLLNotFound
  else
  begin
    inherited Init(AName);
    {create the path of the helpfile with the string resource of the DLL}
    LoadString(Lib, idHelpFile, HelpFile, SizeOf(HelpFile));
    StrCat(HelpFile, 'font.hlp');
  end;
end;

destructor TFontApp.Done;
begin
  inherited Done;
  {Free the library}
  FreeLibrary(Lib);
end;

procedure TFontApp.InitMainWindow;
begin
  MainWindow := New(PFontWindow, Init(nil, 'dlg_main'));
end;

procedure TFontApp.Error(ErrorCode: Integer);
begin
  case ErrorCode of
    em_DLLNotFound:
      begin
        {if the dll could not be loaded display the message and fail the app}
        MessageBox(0, DLLName + ' not found. Please make sure that Windows will found this file!', 'Hard error',
          mb_Ok or mb_IconStop);
        Halt(ErrorCode);
      end;
  else
    inherited Error(ErrorCode);
  end;
end;

var
  App: TFontApp;

begin
  App.Init('Font Demo');
  App.Run;
  App.Done;
end.
